Index: kernel/generic/src/main/kinit.c
===================================================================
--- kernel/generic/src/main/kinit.c	(revision a35b458e9db1ca95e679799dc7c1b12c83359ca3)
+++ kernel/generic/src/main/kinit.c	(revision 8e3153b5c08b4ce5f35bc4675add10df0f29bc69)
@@ -265,9 +265,9 @@
 				    PERM_IO_MANAGER | PERM_IRQ_REG);
 
-				if (!ipc_phone_0) {
-					ipc_phone_0 = &programs[i].task->answerbox;
+				if (!ipc_box_0) {
+					ipc_box_0 = &programs[i].task->answerbox;
 					/*
 					 * Hold the first task so that the
 					 * ipc_phone_0 remains a valid pointer
 					 * even if the first task exits for
 					 * whatever reason.
@@ -265,9 +265,9 @@
 					/*
-					 * Hold the first task so that the
-					 * ipc_phone_0 remains a valid pointer
+					 * Hold the first task so that
+					 * ipc_box_0 remains a valid pointer
 					 * even if the first task exits for
 					 * whatever reason.
